.json-view{display:block;color:#4d4d4d;text-align:left;--json-property:#009033;--json-index:#676dff;--json-number:#676dff;--json-string:#b2762e;--json-boolean:#dc155e;--json-null:#dc155e}.json-view .json-view--property{color:var(--json-property)}.json-view .json-view--index{color:var(--json-index)}.json-view .json-view--number{color:var(--json-number)}.json-view .json-view--string{color:var(--json-string)}.json-view .json-view--boolean{color:var(--json-boolean)}.json-view .json-view--null{color:var(--json-null)}.json-view .jv-indent{padding-left:1em}.json-view .jv-chevron{display:inline-block;vertical-align:-20%;cursor:pointer;opacity:.4;width:1em;height:1em}:is(.json-view .jv-chevron:hover,.json-view .jv-size:hover+.jv-chevron){opacity:.8}.json-view .jv-size{cursor:pointer;opacity:.4;font-size:.875em;font-style:italic;margin-left:.5em;vertical-align:-5%;line-height:1}.json-view .json-view--link svg,.json-view :is(.json-view--copy,.json-view--edit){display:none;width:1em;height:1em;margin-left:.25em;cursor:pointer}.json-view .json-view--input{width:120px;margin-left:.25em;border-radius:4px;border:1px solid;padding:0 4px;font-size:87.5%;line-height:1.25;background:#0000}.json-view .json-view--deleting{outline:1px solid #da0000;background-color:#da000011;-webkit-text-decoration-line:line-through;text-decoration-line:line-through}:is(.json-view:hover,.json-view--pair:hover)>.json-view--link svg,:is(.json-view:hover,.json-view--pair:hover)>:is(.json-view--copy,.json-view--edit){display:inline-block}.json-view .jv-button{background:#0000;outline:none;border:none;cursor:pointer;color:inherit}.json-view .cursor-pointer{cursor:pointer}.json-view svg{vertical-align:-10%}.jv-size-chevron~svg{vertical-align:-16%}.json-view_a11y{color:#545454;--json-property:#aa5d00;--json-index:#007299;--json-number:#007299;--json-string:green;--json-boolean:#d91e18;--json-null:#d91e18}.json-view_github{color:#005cc5;--json-property:#005cc5;--json-index:#005cc5;--json-number:#005cc5;--json-string:#032f62;--json-boolean:#005cc5;--json-null:#005cc5}.json-view_vscode{color:#005cc5;--json-property:#0451a5;--json-index:#00f;--json-number:#00f;--json-string:#a31515;--json-boolean:#00f;--json-null:#00f}.json-view_atom{color:#383a42;--json-property:#e45649;--json-index:#986801;--json-number:#986801;--json-string:#50a14f;--json-boolean:#0184bc;--json-null:#0184bc}.json-view_winter-is-coming{color:#0431fa;--json-property:#3a9685;--json-index:#ae408b;--json-number:#ae408b;--json-string:#8123a9;--json-boolean:#0184bc;--json-null:#0184bc}@import url("https://fonts.googleapis.com/css2?family=Inter:wght@400;500;600;700&display=swap");.TextEditor_tiptap__x4zbW{background:#0000;border-radius:0 0 5px 5px;margin-bottom:1rem;caret-color:#0070f3;font-family:Inter,sans-serif;position:relative;width:100%}.TextEditor_tiptap__x4zbW>*+*{margin-top:0}.TextEditor_tiptap__x4zbW ul{padding-left:1.5rem;list-style:disc}.TextEditor_tiptap__x4zbW ol{padding-left:1.5rem;list-style:decimal}.TextEditor_tiptap__x4zbW h1,.TextEditor_tiptap__x4zbW h2,.TextEditor_tiptap__x4zbW h3,.TextEditor_tiptap__x4zbW h4,.TextEditor_tiptap__x4zbW h5,.TextEditor_tiptap__x4zbW h6{font-weight:600;line-height:1.2;margin-bottom:1rem}.TextEditor_tiptap__x4zbW h1{font-size:2.5rem}.TextEditor_tiptap__x4zbW h2{font-size:2rem}.TextEditor_tiptap__x4zbW h3{font-size:1.75rem}.TextEditor_tiptap__x4zbW h4,.TextEditor_tiptap__x4zbW h5,.TextEditor_tiptap__x4zbW h6{font-size:1rem}.TextEditor_tiptap__x4zbW h4{margin-bottom:1.33rem}.TextEditor_tiptap__x4zbW h5{margin-bottom:1.67rem}.TextEditor_tiptap__x4zbW h6{margin-bottom:2.33rem}.TextEditor_tiptap__x4zbW code{background-color:#f5f5f5;border-radius:.25rem;color:#0070f3;font-size:.875rem;padding:.2rem .4rem}.TextEditor_tiptap__x4zbW pre{background:#f5f5f5;color:#333;font-family:JetBrainsMono,monospace;padding:1rem;border-radius:.5rem;width:100%}.TextEditor_tiptap__x4zbW code{color:inherit;padding:0;background:none;font-size:.8rem}.TextEditor_tiptap__x4zbW blockquote{padding-left:1rem;border-left:4px solid #0070f3;color:#333;font-style:italic}.TextEditor_tiptap__x4zbW hr{border:none;border-top:1px solid #eaeaea;margin:2rem 0;width:100%}.TextEditor_fullScreenEditor__Afw4n{position:fixed;top:0;left:0;width:100vw;background-color:#fff;z-index:1000;padding:20px;box-sizing:border-box;overflow-y:auto;min-height:60vh}.TextEditor_tiptap__x4zbW .ProseMirror{outline:none;width:100%}.TextEditor_tiptap__x4zbW .ProseMirror p{margin:0}.TextEditor_tiptap__x4zbW .ProseMirror>*+*{margin-top:.75em}.TextEditor_truncatedEditor__SP6RG{max-height:150px;overflow-y:auto;text-overflow:ellipsis;white-space:normal}.TextEditor_fullScreenEditor__Afw4n{height:100vh;overflow:auto}